@@ -3,8 +3,8 @@ from peacedeath.photodiodes import Photodiodes
 from peacedeath.od_measurement import ODmeasurement
 from peacedeath.pumps import Pumps
 from peacedeath import pm
-from peacedeath.experiment import start_experiment, write_parameters_OD_thresholds, write_parameters_drug_doses, \
-    read_parameters_OD_thresholds, read_parameters_drug_doses
+from peacedeath.experiment import start_experiment, _write_parameters_OD_thresholds, _write_parameters_drug_doses, \
+    _read_parameters_OD_thresholds, _read_parameters_drug_doses
 import pandas as pd
 import numpy as np
 import os
@@ -38,6 +38,16 @@ class Experiment:
         self.total_dilution_volume = total_dilution_volume
         self.experiment_thread = None
 
+        try:
+            self.parameters_OD_thresholds = _read_parameters_OD_thresholds(self)
+        except FileNotFoundError:
+            self.parameters_OD_thresholds = [0, 0, 0, 0, 0, 0, 0]
+
+        try:
+            self.parameters_drug_doses = _read_parameters_drug_doses(self)
+        except FileNotFoundError:
+            self.parameters_drug_doses = [0, 0, 0, 0, 0, 0, 0]
+
     def mix(self, speed=70, period=3000):
         if 0 < speed < 30:
             speed = 30
@@ -107,15 +117,17 @@ class Experiment:
         with open(os.path.join(self.name, "stop.experiment"), "w+"):
             pass
 
-    def write_parameters_drug_doses(self, drug_doses=(0, 0, 0, 0, 0, 0, 0)):
-        write_parameters_drug_doses(self, drug_doses=drug_doses)
+    @property
+    def parameters_OD_thresholds(self):
+        return _read_parameters_OD_thresholds(self)
+    @parameters_OD_thresholds.setter
+    def parameters_OD_thresholds(self,thresholds):
+        _write_parameters_OD_thresholds(self, thresholds)
 
-    def read_parameters_drug_doses(self):
-        return read_parameters_drug_doses(self)
-
-    def write_parameters_OD_thresholds(self, OD_thresholds=(0, 0, 0, 0, 0, 0, 0)):
-        write_parameters_OD_thresholds(self, OD_thresholds=OD_thresholds)
-
-    def read_parameters_OD_thresholds(self):
-        return read_parameters_OD_thresholds(self)
 
+    @property
+    def parameters_drug_doses(self):
+        return _read_parameters_drug_doses(self)
+    @parameters_drug_doses.setter
+    def parameters_drug_doses(self, drug_doses):
+        _write_parameters_drug_doses(self, drug_doses)
\ No newline at end of file
