@@ -36,27 +36,27 @@ def make_dilution(pe, tube, death_volume=0, peace_volume=0, extra_vacuum=5):
     pe.mix(30)
 
 
-def write_parameters_drug_doses(pe, drug_doses=(0, 0, 0, 0, 0, 0, 0)):
+def _write_parameters_drug_doses(pe, drug_doses=(0, 0, 0, 0, 0, 0, 0)):
     assert len(drug_doses) == 7
     with open(os.path.join(pe.name, "parameters_dose.csv"), "w+") as f:
         f.write(",".join([str(d) for d in drug_doses]))
 
 
-def read_parameters_drug_doses(pe):
+def _read_parameters_drug_doses(pe):
     df = pd.read_csv(os.path.join(pe.name, "parameters_dose.csv"), header=None)
     drug_doses = np.array(df.values.ravel()).astype(float)
     pe.drug_doses = drug_doses
     return drug_doses
 
 
-def write_parameters_OD_thresholds(pe, OD_thresholds=(0, 0, 0, 0, 0, 0, 0)):
+def _write_parameters_OD_thresholds(pe, OD_thresholds=(0, 0, 0, 0, 0, 0, 0)):
     OD_thresholds = np.array(OD_thresholds).astype(float)
     assert len(OD_thresholds) == 7
     with open(os.path.join(pe.name, "parameters_OD_thresholds.csv"), "w+") as f:
         f.write(",".join([str(thr) for thr in OD_thresholds]))
 
 
-def read_parameters_OD_thresholds(pe):
+def _read_parameters_OD_thresholds(pe):
     OD_thresholds = pd.read_csv(os.path.join(pe.name, "parameters_OD_thresholds.csv"), header=None).values[0]
     OD_thresholds = np.array(OD_thresholds.ravel()).astype(float)
     pe.OD_thresholds = OD_thresholds
@@ -64,8 +64,9 @@ def read_parameters_OD_thresholds(pe):
 
 
 def dilute_if_necessary(pe, total_dilution_volume=10):
-    OD_thresholds = read_parameters_OD_thresholds(pe)  # 7 OD thresholds
-    drug_doses = read_parameters_drug_doses(pe)  # 7 death volumes
+    OD_thresholds = pe.parameters_OD_thresholds
+    drug_doses = pe.parameters_drug_doses
+
     death_volumes = total_dilution_volume * drug_doses/100
     peace_volumes = total_dilution_volume - death_volumes
     for tube in range(7):
@@ -107,25 +108,15 @@ def start_experiment(pe):
         print("####### NO ACTIVE TUBES! #######")
     print("Active tubes: ", dict(zip(range(7), pe.tubes_status_active)))
     pe.mix(pe.mixer_speed)
+
     try:
         pe.last_OD_values = read_last_OD_values(pe)
     except FileNotFoundError:
         pe.last_OD_values = [0]*7
+
     print("Last OD values: ", dict(zip(range(7), pe.last_OD_values)))
-
-    try:
-        pe.drug_doses = read_parameters_drug_doses(pe)
-    except FileNotFoundError:
-        write_parameters_drug_doses(pe)
-        read_parameters_drug_doses(pe)
-    print("Death doses:", dict(zip(range(7), pe.drug_doses)))
-
-    try:
-        pe.OD_thresholds = read_parameters_OD_thresholds(pe)
-    except FileNotFoundError:
-        write_parameters_OD_thresholds(pe)
-        read_parameters_OD_thresholds(pe)
-    print("OD thresholds:", dict(zip(range(7), pe.OD_thresholds)))
+    print("Death doses:", dict(zip(range(7), pe.parameters_drug_doses)))
+    print("OD thresholds:", dict(zip(range(7), pe.parameters_OD_thresholds)))
 
     schedule.clear()
     schedule.every().minute.at(":00").do(pause_mixers_and_measure_OD, pe, mixer_speed=pe.mixer_speed)
