@@ -4,13 +4,11 @@ from peacedeath import pm
 import os
 import time
 
-CURRENT_DATA_FILENAME = "current_data.csv"
-
 class Photodiodes:
     def __init__(self, pe):
         self.pe = pe
         self.dev = pe.dev
-        self.current_file = os.path.join(self.pe.name, CURRENT_DATA_FILENAME)
+        self.log_file_current = os.path.join(self.pe.name, "log_current.csv")
 
 
     def measure_current(self, tube, cycles=10, n_measurements=40, laserOnDelay=10, laserOffDelay=10,
@@ -28,11 +26,11 @@ class Photodiodes:
         return IFS, ISS, IFSoff, ISSoff
 
     def log_current(self, tube, IFS, ISS, IFSoff, ISSoff):
-        if not os.path.exists(self.current_file):
-            with open(self.current_file, "w+") as f:
-                f.write("time, front, side, front_off, side_off\n")
+        if not os.path.exists(self.log_file_current):
+            with open(self.log_file_current, "w+") as f:
+                f.write("time, tube, front, side, front_off, side_off\n")
         current_time=time.ctime()
-        with open(self.current_file,"a") as f:
+        with open(self.log_file_current, "a") as f:
             f.write("{time}, {tube:1d}, {IFS:.2f}, {ISS:.2f}, {IFSoff:.2f}, {ISSoff:.2f}\n".format(time=current_time,
                                                                                                   tube=tube,
                                                                                                   IFS=IFS,
